==> tutti-ui-swing-1.1-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/catches/species/split/CreateSpeciesBatchUIModel.java <==
package fr.ifremer.tutti.ui.swing.content.operation.catches.species.split;

/*
 * #%L
 * Tutti :: UI
 * $Id: CreateSpeciesBatchUIModel.java 512 2013-03-01 20:37:07Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/catches/species/split/CreateSpeciesBatchUIModel.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.collect.ArrayListMultimap;
import com.google.common.collect.Multimap;
import fr.ifremer.tutti.persistence.entities.referential.CaracteristicQualitativeValue;
import fr.ifremer.tutti.persistence.entities.referential.Species;
import fr.ifremer.tutti.ui.swing.util.AbstractTuttiBeanUIModel;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.util.List;

/**
 * Model of {@link CreateSpeciesBatchUI}.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 0.3
 */
public class CreateSpeciesBatchUIModel extends AbstractTuttiBeanUIModel<CreateSpeciesBatchUIModel, CreateSpeciesBatchUIModel> {

    private final static Log log = LogFactory.getLog(CreateSpeciesBatchUIModel.class);

    private static final long serialVersionUID = 1L;

    public static final String PROPERTY_AVAILABLE_SPECIES = "availableSpecies";

    public static final String PROPERTY_SPECIES = "species";

    public static final String PROPERTY_SORTED_UNSORTED_CATEGORY = "sortedUnsortedCategory";

    public static final String PROPERTY_BATCH_WEIGHT = "batchWeight";

    /**
     * All available species (sets by protocol).
     *
     * @since 0.3
     */
    protected List<Species> availableSpecies;

    /**
     * Species to select.
     *
     * @since 0.3
     */
    protected Species species;

    /**
     * Sorted Unsorted category.
     *
     * @since 0.3
     */
    protected CaracteristicQualitativeValue sortedUnsortedCategory;

    /**
     * Incoming batch weight to split.
     *
     * @since 0.3
     */
    protected Float batchWeight;

    /**
     * Already used species by sortedUnsorted category.
     *
     * @since 0.3
     */
    protected final Multimap<CaracteristicQualitativeValue, Species> speciesUsed = ArrayListMultimap.create();

    public CreateSpeciesBatchUIModel() {
        super(CreateSpeciesBatchUIModel.class, null, null);
    }

    public List<Species> getAvailableSpecies() {
        if (log.isDebugEnabled()) {
            log.debug("getAvailableSpecies " + availableSpecies);
        }
        return availableSpecies;
    }

    public void setAvailableSpecies(List<Species> availableSpecies) {

        if (log.isDebugEnabled()) {
            log.debug("setAvailableSpecies " + availableSpecies);
        }
        Object oldValue = getAvailableSpecies();
        this.availableSpecies = availableSpecies;
        firePropertyChange(PROPERTY_AVAILABLE_SPECIES, oldValue, availableSpecies);
    }

    public Species getSpecies() {
        return species;
    }

    public void setSpecies(Species species) {
        Object oldSpecies = getSpecies();
        this.species = species;
        firePropertyChange(PROPERTY_SPECIES, oldSpecies, getSpecies());
    }

    public CaracteristicQualitativeValue getSortedUnsortedCategory() {
        return sortedUnsortedCategory;
    }

    public void setSortedUnsortedCategory(CaracteristicQualitativeValue sortedUnsortedCategory) {
        Object oldSpecies = getSortedUnsortedCategory();
        this.sortedUnsortedCategory = sortedUnsortedCategory;
        firePropertyChange(PROPERTY_SORTED_UNSORTED_CATEGORY, oldSpecies, sortedUnsortedCategory);
    }

    public Float getBatchWeight() {
        return batchWeight;
    }

    public void setBatchWeight(Float batchWeight) {
        Object oldValue = getBatchWeight();
        this.batchWeight = batchWeight;
        firePropertyChange(PROPERTY_BATCH_WEIGHT, oldValue, batchWeight);
    }

    public Multimap<CaracteristicQualitativeValue, Species> getSpeciesUsed() {
        return speciesUsed;
    }

    public boolean isSpeciesAndCategoryAvailable() {
        boolean result = species != null && sortedUnsortedCategory != null &&
                         isSpeciesAndCategoryAvailable(species, sortedUnsortedCategory);
        return result;
    }

    public boolean isSpeciesAndCategoryAvailable(Species species,
                                                 CaracteristicQualitativeValue sortedUnsortedCategory) {
        boolean result = !speciesUsed.containsEntry(sortedUnsortedCategory, species);
        return result;
    }
}

==> tutti-ui-swing-1.1.1-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/catches/species/split/CreateSpeciesBatchUIModel.java <==
package fr.ifremer.tutti.ui.swing.content.operation.catches.species.split;

/*
 * #%L
 * Tutti :: UI
 * $Id: CreateSpeciesBatchUIModel.java 512 2013-03-01 20:37:07Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.1.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/catches/species/split/CreateSpeciesBatchUIModel.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.collect.ArrayListMultimap;
import com.google.common.collect.Multimap;
import fr.ifremer.tutti.persistence.entities.referential.CaracteristicQualitativeValue;
import fr.ifremer.tutti.persistence.entities.referential.Species;
import fr.ifremer.tutti.ui.swing.util.AbstractTuttiBeanUIModel;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.util.List;

/**
 * Model of {@link CreateSpeciesBatchUI}.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 0.3
 */
public class CreateSpeciesBatchUIModel extends AbstractTuttiBeanUIModel<CreateSpeciesBatchUIModel, CreateSpeciesBatchUIModel> {

    private final static Log log = LogFactory.getLog(CreateSpeciesBatchUIModel.class);

    private static final long serialVersionUID = 1L;

    public static final String PROPERTY_AVAILABLE_SPECIES = "availableSpecies";

    public static final String PROPERTY_SPECIES = "species";

    public static final String PROPERTY_SORTED_UNSORTED_CATEGORY = "sortedUnsortedCategory";

    public static final String PROPERTY_BATCH_WEIGHT = "batchWeight";

    /**
     * All available species (sets by protocol).
     *
     * @since 0.3
     */
    protected List<Species> availableSpecies;

    /**
     * Species to select.
     *
     * @since 0.3
     */
    protected Species species;

    /**
     * Sorted Unsorted category.
     *
     * @since 0.3
     */
    protected CaracteristicQualitativeValue sortedUnsortedCategory;

    /**
     * Incoming batch weight to split.
     *
     * @since 0.3
     */
    protected Float batchWeight;

    /**
     * Already used species by sortedUnsorted category.
     *
     * @since 0.3
     */
    protected final Multimap<CaracteristicQualitativeValue, Species> speciesUsed = ArrayListMultimap.create();

    public CreateSpeciesBatchUIModel() {
        super(CreateSpeciesBatchUIModel.class, null, null);
    }

    public List<Species> getAvailableSpecies() {
        if (log.isDebugEnabled()) {
            log.debug("getAvailableSpecies " + availableSpecies);
        }
        return availableSpecies;
    }

    public void setAvailableSpecies(List<Species> availableSpecies) {

        if (log.isDebugEnabled()) {
            log.debug("setAvailableSpecies " + availableSpecies);
        }
        Object oldValue = getAvailableSpecies();
        this.availableSpecies = availableSpecies;
        firePropertyChange(PROPERTY_AVAILABLE_SPECIES, oldValue, availableSpecies);
    }

    public Species getSpecies() {
        return species;
    }

    public void setSpecies(Species species) {
        Object oldSpecies = getSpecies();
        this.species = species;
        firePropertyChange(PROPERTY_SPECIES, oldSpecies, getSpecies());
    }

    public CaracteristicQualitativeValue getSortedUnsortedCategory() {
        return sortedUnsortedCategory;
    }

    public void setSortedUnsortedCategory(CaracteristicQualitativeValue sortedUnsortedCategory) {
        Object oldSpecies = getSortedUnsortedCategory();
        this.sortedUnsortedCategory = sortedUnsortedCategory;
        firePropertyChange(PROPERTY_SORTED_UNSORTED_CATEGORY, oldSpecies, sortedUnsortedCategory);
    }

    public Float getBatchWeight() {
        return batchWeight;
    }

    public void setBatchWeight(Float batchWeight) {
        Object oldValue = getBatchWeight();
        this.batchWeight = batchWeight;
        firePropertyChange(PROPERTY_BATCH_WEIGHT, oldValue, batchWeight);
    }

    public Multimap<CaracteristicQualitativeValue, Species> getSpeciesUsed() {
        return speciesUsed;
    }

    public boolean isSpeciesAndCategoryAvailable() {
        boolean result = species != null && sortedUnsortedCategory != null &&
                         isSpeciesAndCategoryAvailable(species, sortedUnsortedCategory);
        return result;
    }

    public boolean isSpeciesAndCategoryAvailable(Species species,
                                                 CaracteristicQualitativeValue sortedUnsortedCategory) {
        boolean result = !speciesUsed.containsEntry(sortedUnsortedCategory, species);
        return result;
    }
}
